@@ -1,5 +1,5 @@
-#import <swarmobject.h>
-#import <swarmobject/Swarm.h>
+#import <objectbase.h>
+#import <objectbase/Swarm.h>
 #import <space.h>
 #import <activity.h>
 #import <collections.h>
